@@ -15,7 +15,11 @@ final class SuppressionListReason
 {
     public const BOUNCE = 'BOUNCE';
     public const COMPLAINT = 'COMPLAINT';
+    public const UNKNOWN_TO_SDK = 'UNKNOWN_TO_SDK';
 
+    /**
+     * @psalm-assert-if-true self::* $value
+     */
     public static function exists(string $value): bool
     {
         return isset([
